Worker Resources Module
=======================

The worker resources module can be interrogated by the user function on a worker
to obtain the following attributes. The convenience functions below can also be used.

.. automodule:: resources.worker_resources
  :noindex:

.. autoclass:: WorkerResources
  :show-inheritance:
  :member-order: bysource
  :members: get_slots_as_string, set_env_to_slots
  :noindex:
